==> ui-18.1.0.tgz: package/components/transfer/Panel.js <==
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { useCallback, useRef, useMemo } from 'react';
import { useId } from '@react-devui/hooks';
import { LoadingOutlined, SearchOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { DCheckbox } from '../checkbox';
import { DEmpty } from '../empty';
import { DInput } from '../input';
import { usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
import { IS_SELECTED } from './Transfer';
export function DPanel(props) {
    const { dList, dSelectedNum, dState, dTitle, dLoading, dSearchable, dCustomItem, onSelectedChange, onAllSelected, onSearch, onScrollBottom, } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const vsRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const uniqueId = useId();
    const getItemId = (val) => `${dPrefix}transfer-item-${val}-${uniqueId}`;
    const canSelectItem = useCallback((item) => !item.disabled, []);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemKey: (item) => item.value,
        dFocusable: canSelectItem,
    }), [canSelectItem, dList]);
    return (_jsxs("div", Object.assign({ className: `${dPrefix}transfer__panel` }, { children: [_jsxs("div", Object.assign({ className: `${dPrefix}transfer__header` }, { children: [_jsxs(DCheckbox, Object.assign({ dDisabled: dList.length === 0, dModel: dState !== 'mixed' ? dState : undefined, dIndeterminate: dState === 'mixed', onModelChange: (checked) => {
                            onAllSelected(checked);
                        } }, { children: [dSelectedNum, "/", dList.length] })), checkNodeExist(dTitle) && _jsx("div", Object.assign({ className: `${dPrefix}transfer__header-title` }, { children: dTitle }))] })), dSearchable && (_jsx(DInput, { className: `${dPrefix}transfer__search`, dPrefix: _jsx(SearchOutlined, {}), dPlaceholder: t('Search'), onModelChange: onSearch })), _jsxs("div", Object.assign({ className: `${dPrefix}transfer__list-container` }, { children: [dLoading && (_jsx("div", Object.assign({ className: `${dPrefix}transfer__loading` }, { children: _jsx(LoadingOutlined, { dSize: 24, dSpin: true }) }))), _jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria }) => {
                            const { label: itemLabel, value: itemValue, disabled: itemDisabled } = item;
                            return (_createElement("li", Object.assign({}, aria, { key: itemValue, id: getItemId(itemValue), className: getClassName(`${dPrefix}transfer__option`, {
                                    'is-disabled': itemDisabled,
                                }), title: itemLabel, onClick: () => {
                                    if (!itemDisabled) {
                                        onSelectedChange === null || onSelectedChange === void 0 ? void 0 : onSelectedChange(itemValue);
                                    }
                                } }),
                                _jsx(DCheckbox, { dDisabled: itemDisabled, dModel: item[IS_SELECTED] }),
                                _jsx("div", Object.assign({ className: `${dPrefix}transfer__option-content` }, { children: dCustomItem ? dCustomItem(item) : itemLabel }))));
                        }, dSize: 192, onScrollEnd: onScrollBottom }, { children: ({ render, vsList }) => render(_jsx("ul", Object.assign({ className: `${dPrefix}transfer__list`, style: { pointerEvents: dLoading ? 'none' : undefined } }, { children: dList.length === 0 ? _jsx(DEmpty, { className: `${dPrefix}transfer__empty` }) : vsList }))) }))] }))] })));
}

==> ui-18.5.7.tgz: package/components/transfer/Panel.js <==
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { useCallback, useRef, useMemo } from 'react';
import { useId } from '@react-devui/hooks';
import { LoadingOutlined, SearchOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { DCheckbox } from '../checkbox';
import { DEmpty } from '../empty';
import { DInput } from '../input';
import { usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
import { IS_SELECTED } from './Transfer';
export function DPanel(props) {
    const { dList, dSelectedNum, dState, dTitle, dLoading, dSearchable, dVirtual, dCustomItem, onSelectedChange, onAllSelected, onSearch, onScrollBottom, } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const vsRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const uniqueId = useId();
    const getItemId = (val) => `${dPrefix}transfer-item-${val}-${uniqueId}`;
    const canSelectItem = useCallback((item) => !item.disabled, []);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemKey: (item) => item.value,
        dFocusable: canSelectItem,
    }), [canSelectItem, dList]);
    return (_jsxs("div", Object.assign({ className: `${dPrefix}transfer__panel` }, { children: [_jsxs("div", Object.assign({ className: `${dPrefix}transfer__header` }, { children: [_jsxs(DCheckbox, Object.assign({ dDisabled: dList.length === 0, dModel: dState !== 'mixed' ? dState : undefined, dIndeterminate: dState === 'mixed', onModelChange: (checked) => {
                            onAllSelected(checked);
                        } }, { children: [dSelectedNum, "/", dList.length] })), checkNodeExist(dTitle) && _jsx("div", Object.assign({ className: `${dPrefix}transfer__header-title` }, { children: dTitle }))] })), dSearchable && (_jsx(DInput, { className: `${dPrefix}transfer__search`, dPrefix: _jsx(SearchOutlined, {}), dPlaceholder: t('Search'), onModelChange: onSearch })), _jsxs("div", Object.assign({ className: `${dPrefix}transfer__list-container` }, { children: [dLoading && (_jsx("div", Object.assign({ className: `${dPrefix}transfer__loading` }, { children: _jsx(LoadingOutlined, { dSize: 24, dSpin: true }) }))), _jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria }) => {
                            const { label: itemLabel, value: itemValue, disabled: itemDisabled } = item;
                            return (_createElement("li", Object.assign({}, aria, { key: itemValue, id: getItemId(itemValue), className: getClassName(`${dPrefix}transfer__option`, {
                                    'is-disabled': itemDisabled,
                                }), title: itemLabel, onClick: () => {
                                    if (!itemDisabled) {
                                        onSelectedChange === null || onSelectedChange === void 0 ? void 0 : onSelectedChange(itemValue);
                                    }
                                } }),
                                _jsx(DCheckbox, { dDisabled: itemDisabled, dModel: item[IS_SELECTED] }),
                                _jsx("div", Object.assign({ className: `${dPrefix}transfer__option-content` }, { children: dCustomItem ? dCustomItem(item) : itemLabel }))));
                        }, dSize: dVirtual ? 192 : Infinity, onScrollEnd: onScrollBottom }, { children: ({ render, vsList }) => render(_jsx("ul", Object.assign({ className: `${dPrefix}transfer__list`, style: { pointerEvents: dLoading ? 'none' : undefined } }, { children: dList.length === 0 ? _jsx(DEmpty, { className: `${dPrefix}transfer__empty` }) : vsList }))) }))] }))] })));
}
